# -*- coding: UTF-8 -*-
# Generated by Django 2.2.6 on 2019-11-06 09:28

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Bucket',
            fields=[
                ('name', models.SlugField(primary_key=True, serialize=False)),
                ('private', models.BooleanField(default=False, verbose_name='是否是私有空间')),
                ('access_key', models.SlugField()),
                ('secret_key', models.SlugField()),
                ('domain', models.CharField(max_length=127)),
            ],
        ),
        migrations.CreateModel(
            name='Resource',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=127, verbose_name='文件名')),
                ('bucket', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_qiniu.Bucket')),
            ],
            options={
                'unique_together': {('bucket', 'key')},
            },
        ),
    ]
